==> yass-1.07.tar.gz: yass-1.07/assemble.h <==
/*
 *  YASS 1.07
 *  Copyright (C) 2004,2005
 *  YASS Team
 *  Laurent Noe, Gregory Kucherov, Mikhail Roytberg, Christophe Valmir, Steven Corroy
 *  yass@loria.fr
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software contains code derived from the GNU libavl library.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef __ASSEMBLE_H_
#define __ASSEMBLE_H_

#include "tuple.h"

int initialise_deltashift();
int Assemble_Single   (/*in*/ char * data,                          /*in*/ int datasize );
int Assemble_SingleRev(/*in*/ char * datarev,  /*in*/ char * data,  /*in*/ int datasize );


int Assemble_Double(/*in*/ char * data_query, /*in*/ int datasize_query,
		    /*in*/ char * data_text , /*in*/ int datasize_text );
int MultiAssemble_Double(char * data_query, int datasize_query,
			 char * data_text,  int datasize_text, int nbchunks_text, char ** chunkname_text, int * chunksize_text,int * chunkstrt_text);

#endif

==> yass-1.08.tar.gz: yass-1.08/assemble.h <==
/*
 *  YASS 1.08
 *  Copyright (C) 2004,2005
 *  YASS Team
 *  Laurent Noe, Gregory Kucherov, Mikhail Roytberg, Christophe Valmir, Steven Corroy
 *  yass@loria.fr
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software contains code derived from the GNU libavl library.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef __ASSEMBLE_H_
#define __ASSEMBLE_H_

#include "tuple.h"

int initialise_deltashift();
int Assemble_Single( /*in */ char *data, /*in */ int datasize);
int Assemble_SingleRev( /*in */ char *datarev, /*in */ char *data, /*in */
		       int datasize);


int Assemble_Double( /*in */ char *data_query, /*in */ int datasize_query,
		    /*in */ char *data_text, /*in */ int datasize_text);
int MultiAssemble_Double(char *data_query, int datasize_query,
			 char *data_text, int datasize_text,
			 int nbchunks_text, char **chunkname_text,
			 int *chunksize_text, int *chunkstrt_text);

#endif
